==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/da/d65/town__widget_8h.js <==
var town__widget_8h =
[
    [ "TownAuthorityWidgets", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdc", [
      [ "WID_TA_CAPTION", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdca845985fcfe2e6681f47af5071d69330e", null ],
      [ "WID_TA_RATING_INFO", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdca411c3e7bab758163e5bffbe3a7705877", null ],
      [ "WID_TA_COMMAND_LIST", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdcab2b8f7ab726edc8c24d0ebb3c7e49d87", null ],
      [ "WID_TA_SCROLLBAR", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdcaf1f1d7ba5930b1c156b3e2a48a640ccb", null ],
      [ "WID_TA_ACTION_INFO", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdca2ed04f82516022c0730052069a993865", null ],
      [ "WID_TA_EXECUTE", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdca2a6c6d786295c056bd70a9fb9b23cf82", null ]
    ] ],
    [ "TownDirectoryWidgets", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5ac", [
      [ "WID_TD_SORT_ORDER", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5aca4f442a6e6e0041870ae5a99df4112a0c", null ],
      [ "WID_TD_SORT_CRITERIA", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5acabfc5a618d5a612756ed4c65ea84e1667", null ],
      [ "WID_TD_LIST", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5aca10060af86ad7f3082f46eb6148436afc", null ],
      [ "WID_TD_SCROLLBAR", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5aca7f74620906ce5b91ea58d4c341be32c2", null ],
      [ "WID_TD_WORLD_POPULATION", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5aca59ee4d1c1181664083e1c8f4322d3bed", null ]
    ] ],
    [ "TownFoundingWidgets", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091f", [
      [ "WID_TF_NEW_TOWN", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa3e8e244cdce0c65a3d9066a875f5e95d", null ],
      [ "WID_TF_RANDOM_TOWN", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fac83a765080c1e756b973dd1015126023", null ],
      [ "WID_TF_MANY_RANDOM_TOWNS", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa5799baef7f1b655ca90dc07820d0639c", null ],
      [ "WID_TF_TOWN_NAME_EDITBOX", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa937dee10c1676312a61220a08f2e5c14", null ],
      [ "WID_TF_TOWN_NAME_RANDOM", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091faf30feb03a0c9c30d6fad36ed6e287ff4", null ],
      [ "WID_TF_SIZE_SMALL", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa72f00cac13efea6d598347778c57810d", null ],
      [ "WID_TF_SIZE_MEDIUM", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa9d46b5515a35f736d99139b84918f820", null ],
      [ "WID_TF_SIZE_LARGE", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa3891a9504eadc2ada4c2bac3cff70d2e", null ],
      [ "WID_TF_SIZE_RANDOM", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa868a90686555e2a531b96646a6926eba", null ],
      [ "WID_TF_CITY", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091faa98c65f2a869b41b6f2782af3a27e861", null ],
      [ "WID_TF_LAYOUT_ORIGINAL", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa85bd20f88a9a9247eff6f5eb81ed5533", null ],
      [ "WID_TF_LAYOUT_BETTER", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fad2a73220bc9375f44f7ab9b18130aed7", null ],
      [ "WID_TF_LAYOUT_GRID2", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa7bad5b0d7aabac531fdb86aca098ff24", null ],
      [ "WID_TF_LAYOUT_GRID3", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091faef9497a3222fce17bbf1a7262461aad4", null ],
      [ "WID_TF_LAYOUT_RANDOM", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa2dbd7fbfdaac8d4e92f42ade6c7ac584", null ]
    ] ],
    [ "TownViewWidgets", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26", [
      [ "WID_TV_CAPTION", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26afececce61a471ade68c1df188661f07a", null ],
      [ "WID_TV_VIEWPORT", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a361ca15118b2c76b56d00f5dddb1cc72", null ],
      [ "WID_TV_INFO", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a64553dc806bc48643157c99bca387eb7", null ],
      [ "WID_TV_CENTER_VIEW", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a8ee1cc611e13b5f88e833535f1a26492", null ],
      [ "WID_TV_SHOW_AUTHORITY", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a8a474f441471447c4f446d3778fb28f4", null ],
      [ "WID_TV_CHANGE_NAME", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a8db823fd3dd769f8630ec3246d9fb501", null ],
      [ "WID_TV_EXPAND", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a69216eaa1c8a0d82c30d548dbe2018e0", null ],
      [ "WID_TV_DELETE", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26abee4f5b5adfc31dcff5cb64fd7250606", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/da/d65/town__widget_8h.js <==
var town__widget_8h =
[
    [ "TownAuthorityWidgets", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdc", [
      [ "WID_TA_CAPTION", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdca845985fcfe2e6681f47af5071d69330e", null ],
      [ "WID_TA_ZONE_BUTTON", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdcaaa1eb1aa708c929bb4c8defd78321dec", null ],
      [ "WID_TA_RATING_INFO", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdca411c3e7bab758163e5bffbe3a7705877", null ],
      [ "WID_TA_COMMAND_LIST", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdcab2b8f7ab726edc8c24d0ebb3c7e49d87", null ],
      [ "WID_TA_SCROLLBAR", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdcaf1f1d7ba5930b1c156b3e2a48a640ccb", null ],
      [ "WID_TA_ACTION_INFO", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdca2ed04f82516022c0730052069a993865", null ],
      [ "WID_TA_EXECUTE", "da/d65/town__widget_8h.html#ab4532fc85a5e59baa171d672340dfcdca2a6c6d786295c056bd70a9fb9b23cf82", null ]
    ] ],
    [ "TownDirectoryWidgets", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5ac", [
      [ "WID_TD_SORT_ORDER", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5aca4f442a6e6e0041870ae5a99df4112a0c", null ],
      [ "WID_TD_SORT_CRITERIA", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5acabfc5a618d5a612756ed4c65ea84e1667", null ],
      [ "WID_TD_FILTER", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5aca440cffd54aa2f118db03f701ef399d70", null ],
      [ "WID_TD_LIST", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5aca10060af86ad7f3082f46eb6148436afc", null ],
      [ "WID_TD_SCROLLBAR", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5aca7f74620906ce5b91ea58d4c341be32c2", null ],
      [ "WID_TD_WORLD_POPULATION", "da/d65/town__widget_8h.html#a21aa19bc2ce06aee3c2977f9611fc5aca59ee4d1c1181664083e1c8f4322d3bed", null ]
    ] ],
    [ "TownFoundingWidgets", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091f", [
      [ "WID_TF_NEW_TOWN", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa3e8e244cdce0c65a3d9066a875f5e95d", null ],
      [ "WID_TF_RANDOM_TOWN", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fac83a765080c1e756b973dd1015126023", null ],
      [ "WID_TF_MANY_RANDOM_TOWNS", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa5799baef7f1b655ca90dc07820d0639c", null ],
      [ "WID_TF_TOWN_NAME_EDITBOX", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa937dee10c1676312a61220a08f2e5c14", null ],
      [ "WID_TF_TOWN_NAME_RANDOM", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091faf30feb03a0c9c30d6fad36ed6e287ff4", null ],
      [ "WID_TF_SIZE_SMALL", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa72f00cac13efea6d598347778c57810d", null ],
      [ "WID_TF_SIZE_MEDIUM", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa9d46b5515a35f736d99139b84918f820", null ],
      [ "WID_TF_SIZE_LARGE", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa3891a9504eadc2ada4c2bac3cff70d2e", null ],
      [ "WID_TF_SIZE_RANDOM", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa868a90686555e2a531b96646a6926eba", null ],
      [ "WID_TF_CITY", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091faa98c65f2a869b41b6f2782af3a27e861", null ],
      [ "WID_TF_LAYOUT_ORIGINAL", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa85bd20f88a9a9247eff6f5eb81ed5533", null ],
      [ "WID_TF_LAYOUT_BETTER", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fad2a73220bc9375f44f7ab9b18130aed7", null ],
      [ "WID_TF_LAYOUT_GRID2", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa7bad5b0d7aabac531fdb86aca098ff24", null ],
      [ "WID_TF_LAYOUT_GRID3", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091faef9497a3222fce17bbf1a7262461aad4", null ],
      [ "WID_TF_LAYOUT_RANDOM", "da/d65/town__widget_8h.html#a418f756f58bee117c957561cd0d6091fa2dbd7fbfdaac8d4e92f42ade6c7ac584", null ]
    ] ],
    [ "TownViewWidgets", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26", [
      [ "WID_TV_CAPTION", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26afececce61a471ade68c1df188661f07a", null ],
      [ "WID_TV_VIEWPORT", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a361ca15118b2c76b56d00f5dddb1cc72", null ],
      [ "WID_TV_INFO", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a64553dc806bc48643157c99bca387eb7", null ],
      [ "WID_TV_CENTER_VIEW", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a8ee1cc611e13b5f88e833535f1a26492", null ],
      [ "WID_TV_SHOW_AUTHORITY", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a8a474f441471447c4f446d3778fb28f4", null ],
      [ "WID_TV_CHANGE_NAME", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a8db823fd3dd769f8630ec3246d9fb501", null ],
      [ "WID_TV_CATCHMENT", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a6ddc41d58933eac536b6ca8394fe123b", null ],
      [ "WID_TV_EXPAND", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26a69216eaa1c8a0d82c30d548dbe2018e0", null ],
      [ "WID_TV_DELETE", "da/d65/town__widget_8h.html#a1e79366a00a6924f1165eed64a916a26abee4f5b5adfc31dcff5cb64fd7250606", null ]
    ] ]
];
